==> haskell-half-0.3-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-half.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 half
version:              0.3
visibility:           public
id:                   half-0.3-1whQz1NLuJm4AJtRLcKyhT
key:                  half-0.3-1whQz1NLuJm4AJtRLcKyhT
license:              BSD-3-Clause
copyright:            Copyright (C) 2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/half
synopsis:             Half-precision floating-point
description:          Half-precision floating-point.
category:             Numeric
abi:                  ac6ed1c7c46eb09ff7eff48528844f52
exposed:              True
exposed-modules:      Numeric.Half
import-dirs:          /usr/lib/ghc-8.10.1/site-local/half-0.3
library-dirs:         /usr/lib/ghc-8.10.1/site-local/half-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/half-0.3
hs-libraries:         HShalf-0.3-1whQz1NLuJm4AJtRLcKyhT
depends:
    base-4.14.0.0 deepseq-1.4.4.0 template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-half/html/half.haddock
haddock-html:         /usr/share/doc/haskell-half/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-half-0.3-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-half.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 half
version:              0.3
visibility:           public
id:                   half-0.3-5mE3JZMqFFg9ssGRc0mAi8
key:                  half-0.3-5mE3JZMqFFg9ssGRc0mAi8
license:              BSD-3-Clause
copyright:            Copyright (C) 2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/half
synopsis:             Half-precision floating-point
description:          Half-precision floating-point.
category:             Numeric
abi:                  3be229107a3d35538bc00db72d37106e
exposed:              True
exposed-modules:      Numeric.Half
import-dirs:          /usr/lib/ghc-8.10.1/site-local/half-0.3
library-dirs:         /usr/lib/ghc-8.10.1/site-local/half-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/half-0.3
hs-libraries:         HShalf-0.3-5mE3JZMqFFg9ssGRc0mAi8
depends:
    base-4.14.0.0 deepseq-1.4.4.0 template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-half/html/half.haddock
haddock-html:         /usr/share/doc/haskell-half/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
